@@ -1,7 +1,7 @@
 #ifndef TIMESTAMP_HPP_
 #define TIMESTAMP_HPP_
 /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
-// Name        : Log
+// Name        : TimeStamp
 // Author      : Avi
 // Revision    : $Revision: #31 $
 //
@@ -17,21 +17,33 @@
 #include <string>
 
 namespace ecf {
+namespace TimeStamp {
 
-// returns a string of format : "[%02d:%02d:%02d %d.%d.%d] "
-//                              "[hour:min:sec day.month.year] "
-// i.e                          "[05:26:20 29.10.2014] "
-class TimeStamp {
-public:
-   static std::string now();
-   static void now(std::string&);
-   static void now_in_brief(std::string&);
-private:
-   TimeStamp() = delete;
-   TimeStamp(const TimeStamp&) = delete;
-   const TimeStamp& operator=(const TimeStamp&) = delete;
-};
+/// Generate a 'regular' time stamp.
+///
+/// Format specified as
+///  - "[%02d:%02d:%02d %d.%d.%d] ", considering "[hour:min:sec day.month.year]
+///  "
+///
+/// Results in the following examples
+///  - "[05:26:20 29.10.2014] "
+///  - "[05:26:20 17.1.2023] "
+///
+std::string now();
+void now(std::string&);
 
-}
+/// Generate a 'brief' time stamp.
+///
+/// Format specified as
+///  - "[%02d:%02d:%02d %d.%d] ", considering "[hour:min:sec day.month] "
+///
+/// Results in the following examples
+///  - "[05:26:20 29.10] "
+///  - "[05:26:20 17.1] "
+///
+void now_in_brief(std::string&);
+
+} // namespace TimeStamp
+} // namespace ecf
 
 #endif
