@@ -20,20 +20,20 @@ namespace ecf {
 
 class User {
 public:
-   enum Action   { FOB, FAIL, ADOPT, REMOVE, BLOCK, KILL };
+    enum Action { FOB, FAIL, ADOPT, REMOVE, BLOCK, KILL };
 
-   static bool valid_user_action( const std::string& );
-   static Action user_action( const std::string& );
-   static std::string to_string(Action);
+    static bool valid_user_action(const std::string&);
+    static Action user_action(const std::string&);
+    static std::string to_string(Action);
 
-   // return login name: will throw if there are any errors
-   static std::string login_name();
+    // return login name: will throw if there are any errors
+    static std::string login_name();
 
 private:
-   User(const User&) = delete;
-   const User& operator=(const User&) = delete;
-   User() = delete;
+    User(const User&)                  = delete;
+    const User& operator=(const User&) = delete;
+    User()                             = delete;
 };
 
-}
+} // namespace ecf
 #endif
