@@ -12,27 +12,28 @@
 //
 // Description :
 //============================================================================
+#include "CalendarParser.hpp"
+
 #include <stdexcept>
 
-#include "CalendarParser.hpp"
 #include "Suite.hpp"
 
 using namespace ecf;
 using namespace std;
 
-bool CalendarParser::doParse( const std::string& line, std::vector<std::string >& lineTokens )
-{
-   if ( lineTokens.size() < 2 ) {
-      throw std::runtime_error( "CalendarParser::doParse: Invalid calendar :" + line );
-   }
-   if ( nodeStack().empty() ) {
-      throw std::runtime_error("CalendarParser::doParse: Could not add calendar as node stack is empty at line: " + line );
-   }
+bool CalendarParser::doParse(const std::string& line, std::vector<std::string>& lineTokens) {
+    if (lineTokens.size() < 2) {
+        throw std::runtime_error("CalendarParser::doParse: Invalid calendar :" + line);
+    }
+    if (nodeStack().empty()) {
+        throw std::runtime_error("CalendarParser::doParse: Could not add calendar as node stack is empty at line: " +
+                                 line);
+    }
 
-   Suite* suite =  nodeStack_top()->isSuite();
-   if (!suite) throw std::runtime_error("Calendar can only be added to suites and not " + nodeStack_top()->debugType()  );
-   suite->set_calendar().read_state(line,lineTokens);
+    Suite* suite = nodeStack_top()->isSuite();
+    if (!suite)
+        throw std::runtime_error("Calendar can only be added to suites and not " + nodeStack_top()->debugType());
+    suite->set_calendar().read_state(line, lineTokens);
 
-   return true;
+    return true;
 }
-
