@@ -3,14 +3,14 @@
 //============================================================================
 // Name        :
 // Author      : Avi
-// Revision    : $Revision: #10 $ 
+// Revision    : $Revision: #10 $
 //
 // Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0 
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-// In applying this licence, ECMWF does not waive the privileges and immunities 
-// granted to it by virtue of its status as an intergovernmental organisation 
-// nor does it submit to any jurisdiction. 
+// This software is licensed under the terms of the Apache Licence version 2.0
+// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+// In applying this licence, ECMWF does not waive the privileges and immunities
+// granted to it by virtue of its status as an intergovernmental organisation
+// nor does it submit to any jurisdiction.
 //
 // Description :
 //               edit fred 'val'
@@ -38,11 +38,14 @@
 
 class VariableParser : public Parser {
 public:
-   explicit VariableParser(DefsStructureParser* p, bool parsing_defs = false) : Parser(p), parsing_defs_(parsing_defs) {}
-	const char* keyword() const override { return "edit"; }
-	bool doParse( const std::string& line, std::vector<std::string >& lineTokens ) override;
+    explicit VariableParser(DefsStructureParser* p, bool parsing_defs = false)
+        : Parser(p),
+          parsing_defs_(parsing_defs) {}
+    const char* keyword() const override { return "edit"; }
+    bool doParse(const std::string& line, std::vector<std::string>& lineTokens) override;
+
 private:
-	bool parsing_defs_;
+    bool parsing_defs_;
 };
 
 #endif
