@@ -3,14 +3,14 @@
 /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
 // Name        :
 // Author      : Avi
-// Revision    : $Revision: #8 $ 
+// Revision    : $Revision: #8 $
 //
 // Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0 
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-// In applying this licence, ECMWF does not waive the privileges and immunities 
-// granted to it by virtue of its status as an intergovernmental organisation 
-// nor does it submit to any jurisdiction. 
+// This software is licensed under the terms of the Apache Licence version 2.0
+// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+// In applying this licence, ECMWF does not waive the privileges and immunities
+// granted to it by virtue of its status as an intergovernmental organisation
+// nor does it submit to any jurisdiction.
 //
 // Description :
 /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
@@ -28,25 +28,23 @@ class AbstractServer;
 //================================================================================
 class SStatsCmd final : public ServerToClientCmd {
 public:
-   explicit SStatsCmd(AbstractServer* as );
-	SStatsCmd() : ServerToClientCmd() {}
+    explicit SStatsCmd(AbstractServer* as);
+    SStatsCmd() : ServerToClientCmd() {}
 
-	void init(AbstractServer* as);
+    void init(AbstractServer* as);
 
-	std::string print() const override;
-	bool equals(ServerToClientCmd*) const override;
-	bool handle_server_response( ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug ) const override;
+    std::string print() const override;
+    bool equals(ServerToClientCmd*) const override;
+    bool handle_server_response(ServerReply& server_reply, Cmd_ptr cts_cmd, bool debug) const override;
 
 private:
- 	Stats stats_;
+    Stats stats_;
 
-   friend class cereal::access;
-   template<class Archive>
-   void serialize(Archive & ar, std::uint32_t const version )
-   {
- 		ar(cereal::base_class< ServerToClientCmd >( this ),
- 		   CEREAL_NVP(stats_));
-  	}
+    friend class cereal::access;
+    template <class Archive>
+    void serialize(Archive& ar, std::uint32_t const version) {
+        ar(cereal::base_class<ServerToClientCmd>(this), CEREAL_NVP(stats_));
+    }
 };
 
 std::ostream& operator<<(std::ostream& os, const SStatsCmd&);
