@@ -3,14 +3,14 @@
 /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
 // Name        :
 // Author      : Avi
-// Revision    : $Revision: #4 $ 
+// Revision    : $Revision: #4 $
 //
 // Copyright 2009- ECMWF.
-// This software is licensed under the terms of the Apache Licence version 2.0 
-// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0. 
-// In applying this licence, ECMWF does not waive the privileges and immunities 
-// granted to it by virtue of its status as an intergovernmental organisation 
-// nor does it submit to any jurisdiction. 
+// This software is licensed under the terms of the Apache Licence version 2.0
+// which can be obtained at http://www.apache.org/licenses/LICENSE-2.0.
+// In applying this licence, ECMWF does not waive the privileges and immunities
+// granted to it by virtue of its status as an intergovernmental organisation
+// nor does it submit to any jurisdiction.
 //
 // Description :
 /////////1/////////2/////////3/////////4/////////5/////////6/////////7/////////8
@@ -27,18 +27,18 @@ namespace ecf {
 
 class SCPort {
 public:
-   /// Check ECF_HOST and ECF_PORT first, otherwise calls next_only
-   static std::string next();
+    /// Check ECF_HOST and ECF_PORT first, otherwise calls next_only
+    static std::string next();
 
-	/// make sure we have a unique port, each time next_only() is called;
-   static std::string next_only(bool debug = false);
+    /// make sure we have a unique port, each time next_only() is called;
+    static std::string next_only(bool debug = false);
 
 private:
-	SCPort() = delete;
-	~SCPort() = delete;
+    SCPort()  = delete;
+    ~SCPort() = delete;
 
-	static int thePort_;
+    static int thePort_;
 };
-}
+} // namespace ecf
 
 #endif
