@@ -13,29 +13,31 @@
 // Description :
 //============================================================================
 
-#include "HttpServer.hpp"
-#include <iostream>
 #include <csignal>
 #include <cstring>
+#include <iostream>
+
+#include "HttpServer.hpp"
 
 int main(int argc, char* argv[]) {
-   // Sometimes we get SIGPIPE through openssl, when server is trying
-   // to write to a socket which client has already closed.
-   // Ignore this signal.
-   sigset_t set;
-   sigemptyset(&set);
-   sigaddset(&set, SIGPIPE);
+    // Sometimes we get SIGPIPE through openssl, when server is trying
+    // to write to a socket which client has already closed.
+    // Ignore this signal.
+    sigset_t set;
+    sigemptyset(&set);
+    sigaddset(&set, SIGPIPE);
 
-   if (pthread_sigmask(SIG_BLOCK, &set, NULL) != 0) {
-       throw std::runtime_error("Failed to set signal mask");
-   }
+    if (pthread_sigmask(SIG_BLOCK, &set, NULL) != 0) {
+        throw std::runtime_error("Failed to set signal mask");
+    }
 
-   try {
-	  HttpServer server(argc, argv);
-	  server.run();
-   } catch (std::exception& e) {
-	  std::cerr << e.what() << std::endl;
-	  return 1;
-   }
-   return 0;
+    try {
+        HttpServer server(argc, argv);
+        server.run();
+    }
+    catch (std::exception& e) {
+        std::cerr << e.what() << std::endl;
+        return 1;
+    }
+    return 0;
 }
