@@ -783,16 +783,16 @@ def test_client_ch_remove(ci):
            
            
 def test_client_get_file(ci):
-    print_test(ci,"test_client_get_file")
+    print_test(ci, "test_client_get_file")
     ci.delete_all()     
     defs = create_defs("test_client_get_file")  
     
     # Also test where user has specified his OWN ECF_JOBOUT (rare)
     t2 = defs.find_abs_node("/test_client_get_file/f1/t2")
     t2_jobout = Test.ecf_home(the_port) + "/test_client_get_file/t2.xx"
-    t2.add_variable("ECF_JOBOUT",t2_jobout)
+    t2.add_variable("ECF_JOBOUT", t2_jobout)
     
-    defs.generate_scripts();
+    defs.generate_scripts()
     msg = defs.check_job_creation(verbose=True)
     assert len(msg) == 0, msg
  
@@ -802,23 +802,103 @@ def test_client_get_file(ci):
     
     while 1:
         if ci.news_local():
-            ci.sync_local() # get the changes, synced with local defs
+            ci.sync_local()  # get the changes, synced with local defs
             suite = ci.get_defs().find_suite("test_client_get_file")
             assert suite is not None, "Expected to find suite"
             if suite.get_state() == State.complete:
-                break;
+                break
         time.sleep(1)
 
     try:
-        for file_t in [ 'script', 'job', 'jobout', 'manual' ]:
-            the_returned_file = ci.get_file('/test_client_get_file/f1/t1',file_t)  # make a request to the server
-            assert len(the_returned_file) > 0,"Expected ci.get_file(/test_client_get_file/f1/t1," + file_t + ") to return something"
+        for task in ['/test_client_get_file/f1/t1', '/test_client_get_file/f1/t2']:
 
-        for file_t in [ 'script', 'job', 'jobout', 'manual' ]:
-            the_returned_file = ci.get_file('/test_client_get_file/f1/t2',file_t)  # make a request to the server
-            assert len(the_returned_file) > 0,"Expected ci.get_file(/test_client_get_file/f1/t2," + file_t + ") to return something"
+            result_string = ci.get_file(task)
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}) to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}) to return something"
 
-        assert os.path.exists(t2_jobout),"User specified ECF_JOBOUT file not created " + t2_jobout
+            result_string = ci.get_file(task, as_bytes=False)
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}, as_bytes=False) to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}, as_bytes=False) to return something"
+
+            result_bytes = ci.get_file(task, as_bytes=True)
+            assert isinstance(result_bytes, bytes), \
+                f"Expected ci.get_file({task}, as_bytes=True) to return 'bytes'"
+            assert len(result_bytes) > 0, \
+                f"Expected ci.get_file({task}, as_bytes=True) to return something"
+
+            assert len(result_string) == len(result_bytes), \
+                f"Expected 'str' result and 'bytes' result to have the same length"
+
+            result_string = ci.get_file(task, max_lines='10')
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}, max_lines='10') to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}, max_lines='10') to return something"
+
+            result_string = ci.get_file(task, max_lines='10', as_bytes=False)
+            assert isinstance(result_string, str), \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=False) to return 'str'"
+            assert len(result_string) > 0, \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=False) to return something"
+
+            result_bytes = ci.get_file(task, max_lines='10', as_bytes=True)
+            assert isinstance(result_bytes, bytes), \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=True) to return 'bytes'"
+            assert len(result_bytes) > 0, \
+                f"Expected ci.get_file({task}, max_lines='10', as_bytes=True) to return something"
+
+            assert len(result_string) == len(result_bytes), \
+                f"Expected 'str' result and 'bytes' result to have the same length"
+
+            for file_type in ['script', 'job', 'jobout', 'manual']:
+
+                result_string = ci.get_file(task, file_type)
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}) to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}) to return something"
+
+                result_string = ci.get_file(task, file_type, as_bytes=False)
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=False) to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=False) to return something"
+
+                result_bytes = ci.get_file(task, file_type, as_bytes=True)
+                assert isinstance(result_bytes, bytes), \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=True) to return 'bytes'"
+                assert len(result_bytes) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, as_bytes=True) to return something"
+
+                assert len(result_string) == len(result_bytes), \
+                    f"Expected 'str' result and 'bytes' result to have the same length"
+
+                result_string = ci.get_file(task, file_type, '10')
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}, '10') to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, '10') to return something"
+
+                result_string = ci.get_file(task, file_type, '10', as_bytes=False)
+                assert isinstance(result_string, str), \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=False) to return 'str'"
+                assert len(result_string) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=False) to return something"
+
+                result_bytes = ci.get_file(task, file_type, '10', as_bytes=True)
+                assert isinstance(result_bytes, bytes), \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=True) to return 'bytes'"
+                assert len(result_bytes) > 0, \
+                    f"Expected ci.get_file({task}, {file_type}, '10', as_bytes=True) to return something"
+
+                assert len(result_string) == len(result_bytes), \
+                    f"Expected 'str' result and 'bytes' result to have the same length"
+
+        assert os.path.exists(t2_jobout), f"User specified ECF_JOBOUT file not created {t2_jobout}"
  
     except RuntimeError as e:
         print(str(e))
