@@ -12,29 +12,29 @@
 #define ATTRIBUTEEDITORFACTORY_HPP
 
 #include <string>
+
 #include "VInfo.hpp"
 
 class AttributeEditor;
 class QWidget;
 
-class AttributeEditorFactory
-{
+class AttributeEditorFactory {
 public:
     explicit AttributeEditorFactory(const std::string& type);
     virtual ~AttributeEditorFactory();
 
-    virtual AttributeEditor* make(VInfo_ptr,QWidget*) = 0;
-    static AttributeEditor* create(const std::string&,VInfo_ptr,QWidget*);
+    virtual AttributeEditor* make(VInfo_ptr, QWidget*) = 0;
+    static AttributeEditor* create(const std::string&, VInfo_ptr, QWidget*);
 
 private:
-    explicit AttributeEditorFactory(const AttributeEditorFactory&) = delete;
+    explicit AttributeEditorFactory(const AttributeEditorFactory&)   = delete;
     AttributeEditorFactory& operator=(const AttributeEditorFactory&) = delete;
 };
 
-template<class T>
-class AttributeEditorMaker : public AttributeEditorFactory
-{
-    AttributeEditor* make(VInfo_ptr info,QWidget* parent) override { return new T(info,parent); }
+template <class T>
+class AttributeEditorMaker : public AttributeEditorFactory {
+    AttributeEditor* make(VInfo_ptr info, QWidget* parent) override { return new T(info, parent); }
+
 public:
     explicit AttributeEditorMaker(const std::string& t) : AttributeEditorFactory(t) {}
 };
