@@ -11,14 +11,14 @@
 #ifndef VIEWER_SRC_CHANGENOTIFYWIDGET_HPP_
 #define VIEWER_SRC_CHANGENOTIFYWIDGET_HPP_
 
-#include <QLinearGradient>
-#include <QToolButton>
-#include <QWidget>
-
 #include <map>
 #include <string>
 #include <vector>
 
+#include <QLinearGradient>
+#include <QToolButton>
+#include <QWidget>
+
 class QHBoxLayout;
 class QLabel;
 class QSignalMapper;
@@ -27,50 +27,48 @@ class ChangeNotify;
 class VProperty;
 class ChangeNotifyWidget;
 
-class ChangeNotifyButton : public QToolButton
-{
-Q_OBJECT
+class ChangeNotifyButton : public QToolButton {
+    Q_OBJECT
 
-friend class ChangeNotifyWidget;
+    friend class ChangeNotifyWidget;
 
 public:
-	explicit ChangeNotifyButton(QWidget* parent=nullptr);
+    explicit ChangeNotifyButton(QWidget* parent = nullptr);
 
-	void setNotifier(ChangeNotify*);
+    void setNotifier(ChangeNotify*);
 
 public Q_SLOTS:
-	void slotAppend();
-	void slotRemoveRow(int);
-	void slotReset();
-	void slotClicked(bool);
+    void slotAppend();
+    void slotRemoveRow(int);
+    void slotReset();
+    void slotClicked(bool);
 
 protected:
-	void updateIcon();
+    void updateIcon();
 
-	ChangeNotify* notifier_{nullptr};
-	QLinearGradient grad_;
+    ChangeNotify* notifier_{nullptr};
+    QLinearGradient grad_;
 };
 
-class ChangeNotifyWidget : public QWidget
-{
-friend class ChangeNotify;
+class ChangeNotifyWidget : public QWidget {
+    friend class ChangeNotify;
 
 public:
-	explicit ChangeNotifyWidget(QWidget *parent=nullptr);
-	~ChangeNotifyWidget() override;
+    explicit ChangeNotifyWidget(QWidget* parent = nullptr);
+    ~ChangeNotifyWidget() override;
 
     void updateVisibility();
-	static void setEnabled(const std::string& id,bool b);
-	static void updateSettings(const std::string& id);
+    static void setEnabled(const std::string& id, bool b);
+    static void updateSettings(const std::string& id);
 
 protected:
-	void addTb(ChangeNotify*);
+    void addTb(ChangeNotify*);
     ChangeNotifyButton* findButton(const std::string& id);
     bool hasVisibleButton() const;
 
-	QHBoxLayout* layout_;
-	std::map<std::string,ChangeNotifyButton*> buttons_;
-	static std::vector<ChangeNotifyWidget*> widgets_;
+    QHBoxLayout* layout_;
+    std::map<std::string, ChangeNotifyButton*> buttons_;
+    static std::vector<ChangeNotifyWidget*> widgets_;
 };
 
 #endif /* VIEWER_SRC_CHANGENOTIFYWIDGET_HPP_ */
