@@ -15,38 +15,34 @@
 
 #include "ui_CodeItemWidget.h"
 
-class CodeItemWidget : public QWidget, protected Ui::CodeItemWidget
-{
-Q_OBJECT
+class CodeItemWidget : public QWidget, protected Ui::CodeItemWidget {
+    Q_OBJECT
 
 public:
-	explicit CodeItemWidget(QWidget *parent=nullptr);
-	~CodeItemWidget() override;
+    explicit CodeItemWidget(QWidget* parent = nullptr);
+    ~CodeItemWidget() override;
 
 protected Q_SLOTS:
-	void on_searchTb__clicked();
-	void on_gotoLineTb__clicked();
-	void on_fontSizeUpTb__clicked();
-	void on_fontSizeDownTb__clicked();
+    void on_searchTb__clicked();
+    void on_gotoLineTb__clicked();
+    void on_fontSizeUpTb__clicked();
+    void on_fontSizeDownTb__clicked();
     void on_reloadTb__clicked();
     void on_copyPathTb__clicked();
     void on_commandTb__clicked();
 
 Q_SIGNALS:
-	void editorFontSizeChanged();
+    void editorFontSizeChanged();
 
 protected:
-	void removeSpacer();
-    virtual void reloadRequested()=0;
+    void removeSpacer();
+    virtual void reloadRequested() = 0;
     virtual void commandRequested() {}
     void setCurrentFileName(const std::string&);
     void clearCurrentFileName();
 
 private:
     std::string currentFileName_;
-
-
 };
 
 #endif
-
