@@ -9,12 +9,9 @@
 
 #include "CustomCommandDialog.hpp"
 
-
-CustomCommandDialog::CustomCommandDialog(QWidget *parent)
-{
+CustomCommandDialog::CustomCommandDialog(QWidget* /*parent*/) {
     setupUi(this);
 
     // when the user clicks the 'Run' button, we close the dialog with ACCEPT
     connect(commandDesigner_->runButton(), SIGNAL(clicked()), this, SLOT(accept()));
-
 }
