@@ -10,13 +10,12 @@
 #ifndef DASHBOARD_HPP_
 #define DASHBOARD_HPP_
 
-#include "Viewer.hpp"
-
 #include <QMainWindow>
 
 #include "ServerFilter.hpp"
 #include "VInfo.hpp"
 #include "VSettings.hpp"
+#include "Viewer.hpp"
 
 class DashboardTitle;
 class DashboardWidget;
@@ -24,46 +23,45 @@ class ServerFilter;
 class ServerItem;
 class VComboSettings;
 
-class Dashboard : public QMainWindow, public ServerFilterObserver
-{
+class Dashboard : public QMainWindow, public ServerFilterObserver {
     Q_OBJECT
 
 public:
-  	Dashboard(QString,QWidget* parent=nullptr);
-	~Dashboard() override;
+    Dashboard(QString, QWidget* parent = nullptr);
+    ~Dashboard() override;
 
-	void reload();
-	void rerender();
+    void reload();
+    void rerender();
 
-	DashboardWidget* addWidget(const std::string& type);
-	DashboardWidget* addDialog(const std::string& type);
-	Viewer::ViewMode viewMode();
-	void setViewMode(Viewer::ViewMode);
-	ServerFilter* serverFilter() const {return serverFilter_;}
-	VInfo_ptr currentSelection();
-	void currentSelection(VInfo_ptr n);
+    DashboardWidget* addWidget(const std::string& type);
+    DashboardWidget* addDialog(const std::string& type);
+    Viewer::ViewMode viewMode();
+    void setViewMode(Viewer::ViewMode);
+    ServerFilter* serverFilter() const { return serverFilter_; }
+    VInfo_ptr currentSelection();
+    void currentSelection(VInfo_ptr n);
     bool selectInTreeView(VInfo_ptr);
     void addSearchDialog();
-    DashboardTitle* titleHandler() const {return titleHandler_;}
+    DashboardTitle* titleHandler() const { return titleHandler_; }
     bool hasMaximised() const;
     bool hasMaximisedApplied() const;
 
-	void notifyServerFilterAdded(ServerItem* item) override;
-	void notifyServerFilterRemoved(ServerItem* item) override;
-	void notifyServerFilterChanged(ServerItem*) override;
-	void notifyServerFilterDelete() override;
+    void notifyServerFilterAdded(ServerItem* item) override;
+    void notifyServerFilterRemoved(ServerItem* item) override;
+    void notifyServerFilterChanged(ServerItem*) override;
+    void notifyServerFilterDelete() override;
 
-	void writeSettings(VComboSettings*);
-	void readSettings(VComboSettings*);
+    void writeSettings(VComboSettings*);
+    void readSettings(VComboSettings*);
 
 Q_SIGNALS:
     void selectionChanged(VInfo_ptr);
-	void contentsChanged();
-	void aboutToDelete();
+    void contentsChanged();
+    void aboutToDelete();
 
 public Q_SLOTS:
-	void slotPopInfoPanel(VInfo_ptr,QString);
-	void slotCommand(VInfo_ptr,QString);
+    void slotPopInfoPanel(VInfo_ptr, QString);
+    void slotCommand(VInfo_ptr, QString);
 
 protected Q_SLOTS:
     void slotDockClose();
@@ -74,27 +72,26 @@ protected Q_SLOTS:
     void slotMaximisedChanged(DashboardWidget* w);
 
 protected:
-   void contextMenuEvent(QContextMenuEvent* e) override;
+    void contextMenuEvent(QContextMenuEvent* e) override;
 
 private:
-    DashboardWidget* addWidgetCore(const std::string& type,bool userAddedView);
-    DashboardWidget* addWidget(const std::string& type,const std::string& dockId,bool userAddedView);
-	QString uniqueDockId();
-	static std::string widgetSettingsId(int i);
+    DashboardWidget* addWidgetCore(const std::string& type, bool userAddedView);
+    DashboardWidget* addWidget(const std::string& type, const std::string& dockId, bool userAddedView);
+    QString uniqueDockId();
+    static std::string widgetSettingsId(int i);
     void initialSelectionInView();
-	VInfo_ptr currentSelectionInView();
-	void addSearchDialog(VInfo_ptr);
+    VInfo_ptr currentSelectionInView();
+    void addSearchDialog(VInfo_ptr);
     void resetMaximised();
     void checkMaximisedState();
 
-	ServerFilter* serverFilter_;
-	DashboardTitle* titleHandler_;
+    ServerFilter* serverFilter_;
+    DashboardTitle* titleHandler_;
     QList<DashboardWidget*> widgets_;
     QList<DashboardWidget*> popupWidgets_;
     QByteArray savedDockState_;
     bool settingsAreRead_;
-	static int maxWidgetNum_;
+    static int maxWidgetNum_;
 };
 
-
 #endif
