@@ -11,10 +11,11 @@
 #define DASHBOARDWIDGET_HPP_
 
 #include <string>
-#include <QDockWidget>
-#include <QWidget>
+
 #include <QAction>
+#include <QDockWidget>
 #include <QIcon>
+#include <QWidget>
 
 #include "VInfo.hpp"
 
@@ -23,62 +24,61 @@ class NodePathWidget;
 class ServerFilter;
 class VComboSettings;
 
-class DashboardWidget : public QWidget
-{
-Q_OBJECT
+class DashboardWidget : public QWidget {
+    Q_OBJECT
 
 public:
-	DashboardWidget(const std::string& type, QWidget* parent=nullptr);
-    ~DashboardWidget() override = default;
+    DashboardWidget(const std::string& type, QWidget* parent = nullptr);
+    ~DashboardWidget() override                                  = default;
 
-    virtual void populateDockTitleBar(DashboardDockTitleWidget*)=0;
-    virtual void populateDialog()=0;
-    virtual void reload()=0;
-	virtual void rerender()=0;
-    virtual bool initialSelectionInView() {return false;}
-	virtual VInfo_ptr currentSelection() {return VInfo_ptr(); }
-    QAction* detachedAction() const {return detachedAction_;}
-    QAction* maximisedAction() const {return maximisedAction_;}
-    virtual QList<QAction*> dockTitleActions() {return QList<QAction*>();}
+    virtual void populateDockTitleBar(DashboardDockTitleWidget*) = 0;
+    virtual void populateDialog()                                = 0;
+    virtual void reload()                                        = 0;
+    virtual void rerender()                                      = 0;
+    virtual bool initialSelectionInView() { return false; }
+    virtual VInfo_ptr currentSelection() { return VInfo_ptr(); }
+    QAction* detachedAction() const { return detachedAction_; }
+    QAction* maximisedAction() const { return maximisedAction_; }
+    virtual QList<QAction*> dockTitleActions() { return QList<QAction*>(); }
 
     bool detached() const;
     void setDetached(bool b);
     bool isMaximised() const;
     void resetMaximised();
     void setEnableMaximised(bool st);
-    bool isInDialog() const {return inDialog_;}
+    bool isInDialog() const { return inDialog_; }
 
     virtual void writeSettings(VComboSettings*);
     virtual void readSettings(VComboSettings*);
     virtual void writeSettingsForDialog() {}
     virtual void readSettingsForDialog() {}
 
-	const std::string type() const {return type_;}
-	void id(const std::string& id) {id_=id;}
+    const std::string type() const { return type_; }
+    void id(const std::string& id) { id_ = id; }
 
 public Q_SLOTS:
-	virtual void setCurrentSelection(VInfo_ptr)=0;
+    virtual void setCurrentSelection(VInfo_ptr) = 0;
 
 Q_SIGNALS:
-    void titleUpdated(QString,QString type=QString());
+    void titleUpdated(QString, QString type = QString());
     void selectionChanged(VInfo_ptr);
     void maximisedChanged(DashboardWidget*);
-    void popInfoPanel(VInfo_ptr,QString);
-    void dashboardCommand(VInfo_ptr,QString);
+    void popInfoPanel(VInfo_ptr, QString);
+    void dashboardCommand(VInfo_ptr, QString);
 
 protected Q_SLOTS:
     void slotDetachedToggled(bool);
     void slotMaximisedToggled(bool);
 
 protected:
-    virtual void detachedChanged()=0;
+    virtual void detachedChanged() = 0;
     void setInDialog(bool);
 
     std::string id_;
-	std::string type_;
-	bool acceptSetCurrent_;
-    QAction *detachedAction_;
-    QAction *maximisedAction_;
+    std::string type_;
+    bool acceptSetCurrent_;
+    QAction* detachedAction_;
+    QAction* maximisedAction_;
     bool ignoreMaximisedChange_;
     NodePathWidget* bcWidget_;
 
@@ -86,5 +86,4 @@ private:
     bool inDialog_;
 };
 
-
 #endif
