@@ -16,13 +16,12 @@
 class VNode;
 class DiagData;
 
-class DiagDataServerItem
-{
+class DiagDataServerItem {
     friend class DiagData;
 
 public:
-    DiagDataServerItem(const std::string& host,const std::string& port,size_t);
-    const std::string& dataAt(int row,int column) const;
+    DiagDataServerItem(const std::string& host, const std::string& port, size_t);
+    const std::string& dataAt(int row, int column) const;
     int findRowByPath(const std::string& path) const;
 
 protected:
@@ -30,25 +29,24 @@ protected:
     std::string host_;
     std::string port_;
     std::vector<std::string> pathData_;
-    std::vector<std::vector<std::string> > data_;
+    std::vector<std::vector<std::string>> data_;
 };
 
-class DiagData
-{
+class DiagData {
 public:
     static DiagData* instance();
 
     void load();
     void loadFile(const std::string&);
-    int count() const {return static_cast<int>(columnNames_.size());}
+    int count() const { return static_cast<int>(columnNames_.size()); }
     const std::string& columnName(int i) const;
-    const std::string& dataAt(VNode*,int column) const;
+    const std::string& dataAt(VNode*, int column) const;
 
 protected:
     DiagData();
     void clear();
     void updateTableModelColumn();
-    DiagDataServerItem* findServerData(const std::string& host,const std::string& port) const;
+    DiagDataServerItem* findServerData(const std::string& host, const std::string& port) const;
 
     static DiagData* instance_;
     std::string fileName_;
