@@ -17,8 +17,8 @@
 #include <QPersistentModelIndex>
 #include <QSet>
 
-//Represents the expand state of a full/part VNode tree. This tree has the same structure
-//as a VNode tree and each VNode object is represented by a ExpandStateNode object.
+// Represents the expand state of a full/part VNode tree. This tree has the same structure
+// as a VNode tree and each VNode object is represented by a ExpandStateNode object.
 
 class TreeNodeModel;
 class AbstractNodeView;
@@ -26,17 +26,16 @@ class QModelIndex;
 class VNode;
 class ExpandStateNode;
 
-class ExpandState
-{
+class ExpandState {
     friend class TreeNodeView;
     friend class CompactNodeView;
 
 public:
-    ExpandState(AbstractNodeView*,TreeNodeModel*);
+    ExpandState(AbstractNodeView*, TreeNodeModel*);
     ~ExpandState();
 
     void save(const VNode*);
-    void collectExpanded(const VNode* node,QSet<QPersistentModelIndex>&);
+    void collectExpanded(const VNode* node, QSet<QPersistentModelIndex>&);
     void saveExpandAll(const VNode* node);
     void saveCollapseAll(const VNode* node);
     void print() const;
@@ -44,15 +43,17 @@ public:
     void updateServerName(const std::string& serverName);
 
 protected:
-    void init(const VNode *vnode);
-	void clear();
-    ExpandStateNode* root() const {return root_;}
-    void save(const VNode *,ExpandStateNode*,const QModelIndex&);
-    void collectExpanded(ExpandStateNode *expand,const VNode* node,
-                 const QModelIndex& nodeIdx,QSet<QPersistentModelIndex>& theSet);
+    void init(const VNode* vnode);
+    void clear();
+    ExpandStateNode* root() const { return root_; }
+    void save(const VNode*, ExpandStateNode*, const QModelIndex&);
+    void collectExpanded(ExpandStateNode* expand,
+                         const VNode* node,
+                         const QModelIndex& nodeIdx,
+                         QSet<QPersistentModelIndex>& theSet);
 
-    bool needToExpandNewChild(ExpandStateNode* expandNode,const std::string&) const;
-    void collectParents(const std::string& fullPath,std::vector<ExpandStateNode*>& parents) const;
+    bool needToExpandNewChild(ExpandStateNode* expandNode, const std::string&) const;
+    void collectParents(const std::string& fullPath, std::vector<ExpandStateNode*>& parents) const;
 
     ExpandStateNode* find(const std::string& fullPath);
 
@@ -62,6 +63,3 @@ protected:
 };
 
 #endif
-
-
-
