@@ -11,27 +11,25 @@
 #ifndef VIEWER_SRC_FILEWATCHER_HPP_
 #define VIEWER_SRC_FILEWATCHER_HPP_
 
-#include <QFileSystemWatcher>
 #include <QFile>
+#include <QFileSystemWatcher>
 #include <QStringList>
 
-class FileWatcher : public QFileSystemWatcher
-{
-Q_OBJECT
+class FileWatcher : public QFileSystemWatcher {
+    Q_OBJECT
 
 public:
-	FileWatcher(const std::string& filePath,qint64 offset,QObject* parent);
+    FileWatcher(const std::string& filePath, qint64 offset, QObject* parent);
 
 protected Q_SLOTS:
-	void slotChanged(const QString& path);
+    void slotChanged(const QString& path);
 
 Q_SIGNALS:
-	void linesAppended(QStringList);
+    void linesAppended(QStringList);
 
 protected:
-	QFile file_;
-	qint64 offset_;
+    QFile file_;
+    qint64 offset_;
 };
 
-
 #endif /* VIEWER_SRC_FILEWATCHER_HPP_ */
