@@ -12,55 +12,49 @@
 #include "Highlighter.hpp"
 #include "InfoProvider.hpp"
 #include "VConfig.hpp"
-#include "VReply.hpp"
 #include "VNode.hpp"
+#include "VReply.hpp"
 
-JobItemWidget::JobItemWidget(QWidget *parent) : CodeItemWidget(parent)
-{
-	messageLabel_->hide();
+JobItemWidget::JobItemWidget(QWidget* parent) : CodeItemWidget(parent) {
+    messageLabel_->hide();
     messageLabel_->setShowTypeTitle(false);
 
-	//Remove the first spacer item!!
-	removeSpacer();
+    // Remove the first spacer item!!
+    removeSpacer();
 
-    //The document becomes the owner of the highlighter
-    new Highlighter(textEdit_->document(),"job");
+    // The document becomes the owner of the highlighter
+    new Highlighter(textEdit_->document(), "job");
 
-    infoProvider_=new JobProvider(this);
+    infoProvider_ = new JobProvider(this);
 
-	//Editor font
-	textEdit_->setFontProperty(VConfig::instance()->find("panel.job.font"));
+    // Editor font
+    textEdit_->setFontProperty(VConfig::instance()->find("panel.job.font"));
 }
 
-JobItemWidget::~JobItemWidget()
-= default;
+JobItemWidget::~JobItemWidget() = default;
 
-QWidget* JobItemWidget::realWidget()
-{
+QWidget* JobItemWidget::realWidget() {
     return this;
 }
 
-void JobItemWidget::reload(VInfo_ptr info)
-{
+void JobItemWidget::reload(VInfo_ptr info) {
     assert(active_);
 
-    if(suspended_)
+    if (suspended_)
         return;
 
     clearContents();
-    info_=info;
+    info_ = info;
     messageLabel_->hide();
 
-    //Info must be a node
-    if(info_ && info_->isNode() && info_->node())
-    {
+    // Info must be a node
+    if (info_ && info_->isNode() && info_->node()) {
         reloadTb_->setEnabled(false);
         infoProvider_->info(info_);
-    }   
+    }
 }
 
-void JobItemWidget::clearContents()
-{
+void JobItemWidget::clearContents() {
     InfoPanelItem::clear();
     textEdit_->clear();
     messageLabel_->hide();
@@ -68,19 +62,16 @@ void JobItemWidget::clearContents()
     clearCurrentFileName();
 }
 
-void JobItemWidget::infoReady(VReply* reply)
-{
+void JobItemWidget::infoReady(VReply* reply) {
     Q_ASSERT(reply);
-    QString s=QString::fromStdString(reply->text());
+    QString s = QString::fromStdString(reply->text());
     textEdit_->setPlainText(s);
 
-    if(reply->hasWarning())
-    {
-    	messageLabel_->showWarning(QString::fromStdString(reply->warningText()));
+    if (reply->hasWarning()) {
+        messageLabel_->showWarning(QString::fromStdString(reply->warningText()));
     }
-    else if(reply->hasInfo())
-    {
-    	messageLabel_->showInfo(QString::fromStdString(reply->infoText()));
+    else if (reply->hasInfo()) {
+        messageLabel_->showInfo(QString::fromStdString(reply->infoText()));
     }
 
     fileLabel_->update(reply);
@@ -89,42 +80,33 @@ void JobItemWidget::infoReady(VReply* reply)
     setCurrentFileName(reply->fileName());
 }
 
-void JobItemWidget::infoProgress(VReply* reply)
-{
-    QString s=QString::fromStdString(reply->infoText());
+void JobItemWidget::infoProgress(VReply* reply) {
+    QString s = QString::fromStdString(reply->infoText());
     messageLabel_->showInfo(s);
 }
 
-void JobItemWidget::infoFailed(VReply* reply)
-{
-    QString s=QString::fromStdString(reply->errorText());
+void JobItemWidget::infoFailed(VReply* reply) {
+    QString s = QString::fromStdString(reply->errorText());
     messageLabel_->showError(s);
     reloadTb_->setEnabled(true);
 }
 
-void JobItemWidget::reloadRequested()
-{
+void JobItemWidget::reloadRequested() {
     reload(info_);
 }
 
-void JobItemWidget::updateState(const FlagSet<ChangeFlag>& flags)
-{
-    if(flags.isSet(SuspendedChanged))
-    {
-        //Suspend
-        if(suspended_)
-        {
+void JobItemWidget::updateState(const FlagSet<ChangeFlag>& flags) {
+    if (flags.isSet(SuspendedChanged)) {
+        // Suspend
+        if (suspended_) {
             reloadTb_->setEnabled(false);
         }
-        //Resume
-        else
-        {
-            if(info_ && info_->node())
-            {
+        // Resume
+        else {
+            if (info_ && info_->node()) {
                 reloadTb_->setEnabled(true);
             }
-            else
-            {
+            else {
                 clearContents();
             }
         }
