@@ -11,28 +11,26 @@
 #ifndef LIMITEDITOR_HPP
 #define LIMITEDITOR_HPP
 
-#include "ui_LimitEditorWidget.h"
+#include <QStringList>
 
 #include "AttributeEditor.hpp"
 #include "VInfo.hpp"
-
-#include <QStringList>
+#include "ui_LimitEditorWidget.h"
 
 class LimitEditor;
 class QStringListModel;
 
-class LimitEditorWidget :  public QWidget, protected Ui::LimitEditorWidget
-{
-friend class LimitEditor;
+class LimitEditorWidget : public QWidget, protected Ui::LimitEditorWidget {
+    friend class LimitEditor;
+
 public:
-    LimitEditorWidget(QWidget *parent=nullptr);
+    LimitEditorWidget(QWidget* parent = nullptr);
 };
 
-class LimitEditor : public AttributeEditor
-{
-Q_OBJECT
+class LimitEditor : public AttributeEditor {
+    Q_OBJECT
 public:
-    LimitEditor(VInfo_ptr,QWidget* parent=nullptr);
+    LimitEditor(VInfo_ptr, QWidget* parent = nullptr);
     ~LimitEditor() override;
 
 protected Q_SLOTS:
@@ -42,17 +40,17 @@ protected Q_SLOTS:
     void slotKill();
     void slotSelection(const QItemSelection& /*selected*/, const QItemSelection& /*deselected*/);
     void slotLookUp();
-    void slotDoubleClicked(const QModelIndex &index);
+    void slotDoubleClicked(const QModelIndex& index);
 
 protected:
     void resetValue() override;
     void apply() override;
     bool isValueChanged() override;
-    void buildList(VAttribute *a);
+    void buildList(VAttribute* a);
     void remove(bool all);
     void nodeChanged(const std::vector<ecf::Aspect::Type>& a) override;
     void setModelData(QStringList lst);
-    void lookup(const QModelIndex &index);
+    void lookup(const QModelIndex& index);
     void readSettings();
     void writeSettings();
 
@@ -64,5 +62,3 @@ protected:
 };
 
 #endif // LIMITEDITOR_HPP
-
-
