@@ -10,51 +10,49 @@
 #ifndef NODEPANEL_HPP_
 #define NODEPANEL_HPP_
 
-#include "Viewer.hpp"
+#include <QIcon>
+#include <boost/property_tree/ptree.hpp>
+
 #include "TabWidget.hpp"
 #include "VInfo.hpp"
-
-#include <QIcon>
-
-#include <boost/property_tree/ptree.hpp>
+#include "Viewer.hpp"
 
 class Dashboard;
 class DashboardTitle;
 class ServerFilter;
 class VComboSettings;
 
-class NodePanel : public TabWidget
-{
+class NodePanel : public TabWidget {
     Q_OBJECT
 
 public:
-	explicit NodePanel(QWidget* parent=nullptr);
-	~NodePanel() override;
+    explicit NodePanel(QWidget* parent = nullptr);
+    ~NodePanel() override;
 
-	void setViewMode(Viewer::ViewMode);
-	Viewer::ViewMode viewMode();
+    void setViewMode(Viewer::ViewMode);
+    Viewer::ViewMode viewMode();
 
-	ServerFilter* serverFilter();
+    ServerFilter* serverFilter();
 
-	Dashboard* currentDashboard();
-	void addWidget();
-	void resetWidgets(QStringList);
-	void reload();
-	void rerender();
-	void refreshCurrent();
-	void resetCurrent();
-	VInfo_ptr currentSelection();
+    Dashboard* currentDashboard();
+    void addWidget();
+    void resetWidgets(QStringList);
+    void reload();
+    void rerender();
+    void refreshCurrent();
+    void resetCurrent();
+    VInfo_ptr currentSelection();
     bool selectInTreeView(VInfo_ptr);
-	void addToDashboard(const std::string& type);
-	void init();
-	void openDialog(VInfo_ptr,const std::string& type);
-	void addSearchDialog();
+    void addToDashboard(const std::string& type);
+    void init();
+    void openDialog(VInfo_ptr, const std::string& type);
+    void addSearchDialog();
 
-	void writeSettings(VComboSettings*);
-	void readSettings(VComboSettings*);
+    void writeSettings(VComboSettings*);
+    void readSettings(VComboSettings*);
 
 public Q_SLOTS:
-	void slotCurrentWidgetChanged(int);
+    void slotCurrentWidgetChanged(int);
     void slotSelection(VInfo_ptr);
     void slotNewTab();
     void slotSelectionChangedInWidget(VInfo_ptr);
@@ -64,20 +62,20 @@ protected Q_SLOTS:
     void slotTabTitle(DashboardTitle* w);
 
 Q_SIGNALS:
-	void itemInfoChanged(QString);
-	void currentWidgetChanged();
+    void itemInfoChanged(QString);
+    void currentWidgetChanged();
     void selectionChangedInCurrent(VInfo_ptr);
-	void contentsChanged();
+    void contentsChanged();
 
 protected:
-    void resizeEvent(QResizeEvent *e) override;
+    void resizeEvent(QResizeEvent* e) override;
     void adjustTabTitle();
     int tabAreaWidth() const;
 
     Dashboard* addWidget(QString);
-	void tabBarCommand(QString, int) override;
-	Dashboard* nodeWidget(int index);
-	static std::string tabSettingsId(int i);
+    void tabBarCommand(QString, int) override;
+    Dashboard* nodeWidget(int index);
+    static std::string tabSettingsId(int i);
 };
 
 #endif
