@@ -12,59 +12,57 @@
 
 #include <QAbstractItemModel>
 #include <QDialog>
-#include <QSettings>
 #include <QElapsedTimer>
+#include <QSettings>
 #include <QWidget>
 
 #include "ServerFilter.hpp"
 #include "VInfo.hpp"
-
 #include "ui_NodeSearchWidget.h"
 
 class NodeQuery;
 class NodeQueryEngine;
 class NodeQueryResultModel;
 
-class NodeSearchWidget : public QWidget, protected Ui::NodeSearchWidget
-{
+class NodeSearchWidget : public QWidget, protected Ui::NodeSearchWidget {
     Q_OBJECT
 
 public:
-    explicit NodeSearchWidget(QWidget *parent = nullptr);
+    explicit NodeSearchWidget(QWidget* parent = nullptr);
     ~NodeSearchWidget() override;
 
     void setServerFilter(ServerFilter*);
     void setRootNode(VInfo_ptr);
 
-    void writeSettings(QSettings &settings);
-    void readSettings(const QSettings &settings);
+    void writeSettings(QSettings& settings);
+    void readSettings(const QSettings& settings);
 
 public Q_SLOTS:
     void slotFind();
-	void slotStop();
+    void slotStop();
 
 protected Q_SLOTS:
     void slotShowDefPanel(bool);
     void slotShowQueryPanel(bool);
-	void slotClose();
-	void slotQueryStarted();
-	void slotQueryFinished();
-	void slotQueryEnabledChanged(bool queryEnabled);
+    void slotClose();
+    void slotQueryStarted();
+    void slotQueryFinished();
+    void slotQueryEnabledChanged(bool queryEnabled);
 
 Q_SIGNALS:
-	void closeClicked();
+    void closeClicked();
     void selectionChanged(VInfo_ptr);
-    void infoPanelCommand(VInfo_ptr,QString);
+    void infoPanelCommand(VInfo_ptr, QString);
 
 private:
     void adjustColumns();
     void adjustButtonState();
     void adjustButtonState(bool);
 
-	NodeQuery* query_{nullptr};
-	NodeQueryEngine* engine_;
-	NodeQueryResultModel* model_;
-	bool columnsAdjusted_{false};
+    NodeQuery* query_{nullptr};
+    NodeQueryEngine* engine_;
+    NodeQueryResultModel* model_;
+    bool columnsAdjusted_{false};
     QElapsedTimer elapsed_;
 };
 
