@@ -11,50 +11,48 @@
 #ifndef OUTPUTCHACHE_HPP_
 #define OUTPUTCHACHE_HPP_
 
-#include <QMap>
-#include <QElapsedTimer>
-#include <QTimer>
-#include <QSet>
-
 #include <sstream>
 
+#include <QElapsedTimer>
+#include <QMap>
+#include <QSet>
+#include <QTimer>
+
 #include "OutputClient.hpp"
 #include "VFile.hpp"
 #include "VInfo.hpp"
 
-
 class OutputCache;
 
 struct OutputCacheItem
 {
-  friend class OutputCache;
+    friend class OutputCache;
 
 public:
-    OutputCacheItem(QString id,VFile_ptr file);
-    VFile_ptr file() const {return file_;}
+    OutputCacheItem(QString id, VFile_ptr file);
+    VFile_ptr file() const { return file_; }
     bool isAttached() const;
-    friend std::ostream& operator<<(std::ostream& stream,const OutputCacheItem& item);
+    friend std::ostream& operator<<(std::ostream& stream, const OutputCacheItem& item);
 
 protected:
     void attach();
     void detach();
 
     QString id_;
-    VFile_ptr file_;   
+    VFile_ptr file_;
     bool used_;
     QElapsedTimer inTimeOut_;
 };
 
-class OutputCache:  public QObject
-{
+class OutputCache : public QObject {
     Q_OBJECT
 
-public:   
-    OutputCache(QObject* parent=nullptr);
+public:
+    OutputCache(QObject* parent = nullptr);
     ~OutputCache() override;
 
-    OutputCacheItem* add(VInfo_ptr info,const std::string& sourcePath,VFile_ptr file);
-    OutputCacheItem* attachOne(VInfo_ptr info,const std::string& fileName);
+    OutputCacheItem* add(VInfo_ptr info, const std::string& sourcePath, VFile_ptr file);
+    OutputCacheItem* attachOne(VInfo_ptr info, const std::string& fileName);
     void detach();
     void clear();
     void print();
@@ -69,11 +67,10 @@ private:
     void startTimer();
     void stopTimer();
 
-    QMap<QString,OutputCacheItem*> items_;
+    QMap<QString, OutputCacheItem*> items_;
     int timeOut_;
     int maxAttachedPeriod_;
     QTimer* timer_;
 };
 
 #endif // OUTPUTCHACHE_HPP
-
