@@ -17,18 +17,17 @@
 class LineNumberArea;
 class GotoLineDialog;
 
-class PlainTextEdit : public QPlainTextEdit, public VPropertyObserver
-{
-Q_OBJECT
+class PlainTextEdit : public QPlainTextEdit, public VPropertyObserver {
+    Q_OBJECT
 
 public:
     explicit PlainTextEdit(QWidget* parent = nullptr);
-	~PlainTextEdit() override;
+    ~PlainTextEdit() override;
 
-    void lineNumberAreaPaintEvent(QPaintEvent *event);
-    int  lineNumberAreaWidth();
+    void lineNumberAreaPaintEvent(QPaintEvent* event);
+    int lineNumberAreaWidth();
 
-    bool showLineNumbers()                 {return showLineNum_;}
+    bool showLineNumbers() { return showLineNum_; }
     void setShowLineNumbers(bool b);
 
     void toDocStart();
@@ -36,77 +35,74 @@ public:
     void toLineStart();
     void toLineEnd();
 
-    void cursorRowCol(int *row, int *col);
-    QChar characterBehindCursor(QTextCursor *cursor=nullptr);
+    void cursorRowCol(int* row, int* col);
+    QChar characterBehindCursor(QTextCursor* cursor = nullptr);
 
     int numLinesSelected();
-    bool findString(const QString &,QTextDocument::FindFlags,bool replace=false,const QString &r=emptyString_);
+    bool findString(const QString&, QTextDocument::FindFlags, bool replace = false, const QString& r = emptyString_);
 
     void setFontProperty(VProperty* p);
     void updateFont();
     void notifyChange(VProperty* p) override;
-    bool isHyperlinkEnabled() {return hyperlinkEnabled_;}
+    bool isHyperlinkEnabled() { return hyperlinkEnabled_; }
     bool setHyperlinkEnabled(bool h);
 
 public Q_SLOTS:
-     void gotoLine();
-     void slotZoomIn();
-     void slotZoomOut();
+    void gotoLine();
+    void slotZoomIn();
+    void slotZoomOut();
 
 private Q_SLOTS:
-     void updateLineNumberAreaWidth(int newBlockCount);
-     void updateLineNumberArea(const QRect &, int);
-     void gotoLine(int line);
+    void updateLineNumberAreaWidth(int newBlockCount);
+    void updateLineNumberArea(const QRect&, int);
+    void gotoLine(int line);
 
 Q_SIGNALS:
-    void focusRegained ();
+    void focusRegained();
     void focusLost();
     void fontSizeChangedByWheel();
     void hyperlinkActivated(QString link);
 
 protected:
-    void resizeEvent(QResizeEvent *event) override;
-    void focusInEvent(QFocusEvent *event) override;
-    void focusOutEvent(QFocusEvent *event) override;
-    void wheelEvent(QWheelEvent *event) override;
-    void mousePressEvent(QMouseEvent *e) override;
-    void mouseReleaseEvent(QMouseEvent *e) override;
-    void mouseMoveEvent(QMouseEvent *e) override;
-    void keyPressEvent(QKeyEvent *e) override;
+    void resizeEvent(QResizeEvent* event) override;
+    void focusInEvent(QFocusEvent* event) override;
+    void focusOutEvent(QFocusEvent* event) override;
+    void wheelEvent(QWheelEvent* event) override;
+    void mousePressEvent(QMouseEvent* e) override;
+    void mouseReleaseEvent(QMouseEvent* e) override;
+    void mouseMoveEvent(QMouseEvent* e) override;
+    void keyPressEvent(QKeyEvent* e) override;
 
 private:
     void fontSizeChangedByZoom();
 
     bool showLineNum_{true};
-    QWidget *lineNumArea_;
+    QWidget* lineNumArea_;
     int rightMargin_{2};
     bool hyperlinkEnabled_{false};
     QString lastFindString_;
     QString currentLink_;
     QTextDocument::FindFlags lastFindFlags_;
-    GotoLineDialog *gotoLineDialog_{nullptr};
+    GotoLineDialog* gotoLineDialog_{nullptr};
     static QString emptyString_;
 
     QColor numAreaBgCol_;
     QColor numAreaFontCol_;
     QColor numAreaSeparatorCol_;
     QColor numAreaCurrentCol_;
-    VProperty *fontProp_{nullptr};
+    VProperty* fontProp_{nullptr};
 };
 
-
-class LineNumberArea : public QWidget
-{
+class LineNumberArea : public QWidget {
 public:
-    explicit LineNumberArea(PlainTextEdit *editor) : QWidget(editor) {textEditor = editor;}
-    QSize sizeHint() const override {return {textEditor->lineNumberAreaWidth(), 0};}
+    explicit LineNumberArea(PlainTextEdit* editor) : QWidget(editor) { textEditor = editor; }
+    QSize sizeHint() const override { return {textEditor->lineNumberAreaWidth(), 0}; }
 
 protected:
-    void paintEvent(QPaintEvent *event) override { textEditor->lineNumberAreaPaintEvent(event);}
+    void paintEvent(QPaintEvent* event) override { textEditor->lineNumberAreaPaintEvent(event); }
 
 private:
-    PlainTextEdit *textEditor;
+    PlainTextEdit* textEditor;
 };
 
-
 #endif
