@@ -15,27 +15,28 @@
 
 class QPlainTextEdit;
 
-class PlainTextSearchInterface : public AbstractTextEditSearchInterface
-{
+class PlainTextSearchInterface : public AbstractTextEditSearchInterface {
 public:
-	PlainTextSearchInterface();
-	void setEditor(QPlainTextEdit* e) {editor_=e;}
+    PlainTextSearchInterface();
+    void setEditor(QPlainTextEdit* e) { editor_ = e; }
 
-	bool findString (QString str, bool highlightAll, QTextDocument::FindFlags findFlags,
-					 QTextCursor::MoveOperation move, int iteration,StringMatchMode::Mode matchMode) override;
+    bool findString(QString str,
+                    bool highlightAll,
+                    QTextDocument::FindFlags findFlags,
+                    QTextCursor::MoveOperation move,
+                    int iteration,
+                    StringMatchMode::Mode matchMode) override;
 
-	void automaticSearchForKeywords(bool) override;
-	void refreshSearch() override;
+    void automaticSearchForKeywords(bool) override;
+    void refreshSearch() override;
     void clearHighlights() override;
     void disableHighlights() override;
     void enableHighlights() override {}
-	bool highlightsNeedSearch() override {return true;}
-	void gotoLastLine() override;
+    bool highlightsNeedSearch() override { return true; }
+    void gotoLastLine() override;
 
 protected:
-
-	QPlainTextEdit *editor_{nullptr};
-
+    QPlainTextEdit* editor_{nullptr};
 };
 
 #endif /* VIEWER_SRC_PLAINTEXTSEARCHINTERFACE_HPP_ */
