@@ -16,20 +16,17 @@
 
 class AbstractTextSearchInterface;
 
-class PlainTextSearchLine : public TextEditSearchLine
-{
+class PlainTextSearchLine : public TextEditSearchLine {
 public:
-	explicit PlainTextSearchLine(QWidget *parent=nullptr);
-	~PlainTextSearchLine() override;
-	void setEditor(QPlainTextEdit*);
+    explicit PlainTextSearchLine(QWidget* parent = nullptr);
+    ~PlainTextSearchLine() override;
+    void setEditor(QPlainTextEdit*);
 
 private:
-	//The interface is set internally
+    // The interface is set internally
     void setSearchInterface(AbstractTextSearchInterface*) {}
-
 };
 
-
 #if 0
 class PlainTextSearchLine : public AbstractSearchLine
 {
@@ -65,5 +62,4 @@ protected:
 };
 #endif
 
-
 #endif
