@@ -10,46 +10,45 @@
 #ifndef PROPERTYDIALOG_INC_
 #define PROPERTYDIALOG_INC_
 
-#include "ui_PropertyDialog.h"
-
 #include <QDialog>
 
+#include "ui_PropertyDialog.h"
+
 class QAbstractButton;
 
 class PropertyEditor;
 class VProperty;
 
-class PropertyDialog : public QDialog, private Ui::PropertyDialog
-{
+class PropertyDialog : public QDialog, private Ui::PropertyDialog {
+
+    Q_OBJECT
 
-Q_OBJECT    
-    
 public:
-    explicit PropertyDialog(QWidget *parent=nullptr);
+    explicit PropertyDialog(QWidget* parent = nullptr);
     ~PropertyDialog() override = default;
 
-    bool isConfigChanged() const {return configChanged_;}
+    bool isConfigChanged() const { return configChanged_; }
     void showPage(QString);
 
-    //Called from VConfigLoader
+    // Called from VConfigLoader
     static void load(VProperty*);
 
 public Q_SLOTS:
     void accept() override;
     void reject() override;
-    void slotChangePage(QListWidgetItem *current, QListWidgetItem *previous);
+    void slotChangePage(QListWidgetItem* current, QListWidgetItem* previous);
     void slotButton(QAbstractButton*);
 
 Q_SIGNALS:
-	void configChanged();
+    void configChanged();
 
 private:
     void build();
-    void addPage(QWidget *w,QPixmap pix,QString txt);
+    void addPage(QWidget* w, QPixmap pix, QString txt);
     void manageChange(bool);
     void apply();
 
-    void closeEvent(QCloseEvent * event) override;
+    void closeEvent(QCloseEvent* event) override;
     void readSettings();
     void writeSettings();
 
@@ -57,8 +56,6 @@ private:
     bool configChanged_{false};
 
     static VProperty* prop_;
-
 };
 
 #endif
-
