@@ -9,26 +9,23 @@
 
 #include "RichTextEdit.hpp"
 
-#include <QtGlobal>
 #include <QDebug>
 #include <QFile>
 #include <QPainter>
 #include <QTextBlock>
 #include <QWheelEvent>
+#include <QtGlobal>
 
+#include "UiLog.hpp"
 #include "VConfig.hpp"
 #include "ViewerUtil.hpp"
-#include "UiLog.hpp"
 
-RichTextEdit::RichTextEdit(QWidget * parent) :
-    QTextBrowser(parent)
-{
+RichTextEdit::RichTextEdit(QWidget* parent) : QTextBrowser(parent) {
     setFont(ViewerUtil::findMonospaceFont());
 }
 
-RichTextEdit::~RichTextEdit()
-{
-    if(fontProp_)
+RichTextEdit::~RichTextEdit() {
+    if (fontProp_)
         fontProp_->removeObserver(this);
 }
 
@@ -36,48 +33,40 @@ RichTextEdit::~RichTextEdit()
 // Fontsize management
 //---------------------------------------------
 
-void RichTextEdit::setFontProperty(VProperty* p)
-{
-    fontProp_=p;
+void RichTextEdit::setFontProperty(VProperty* p) {
+    fontProp_ = p;
     fontProp_->addObserver(this);
     updateFont();
 }
 
-void RichTextEdit::slotZoomIn()
-{
+void RichTextEdit::slotZoomIn() {
     zoomIn();
     fontSizeChangedByZoom();
 }
 
-void RichTextEdit::slotZoomOut()
-{
-    int oriSize=font().pointSize();
+void RichTextEdit::slotZoomOut() {
+    int oriSize = font().pointSize();
     zoomOut();
 
-    if(font().pointSize() != oriSize)
+    if (font().pointSize() != oriSize)
         fontSizeChangedByZoom();
 }
 
-void RichTextEdit::fontSizeChangedByZoom()
-{
-    if(fontProp_)
+void RichTextEdit::fontSizeChangedByZoom() {
+    if (fontProp_)
         fontProp_->setValue(font());
 }
 
-void RichTextEdit::updateFont()
-{
-    if(fontProp_)
-    {
-        auto f=fontProp_->value().value<QFont>();
-        if(font() != f)
+void RichTextEdit::updateFont() {
+    if (fontProp_) {
+        auto f = fontProp_->value().value<QFont>();
+        if (font() != f)
             setFont(f);
     }
 }
 
-void RichTextEdit::notifyChange(VProperty* p)
-{
-    if(fontProp_ ==p)
-    {
+void RichTextEdit::notifyChange(VProperty* p) {
+    if (fontProp_ == p) {
         setFont(p->value().value<QFont>());
     }
 }
