@@ -19,8 +19,8 @@
 #include <QWidget>
 
 #include "FontMetrics.hpp"
-#include "ServerObserver.hpp"
 #include "ServerComObserver.hpp"
+#include "ServerObserver.hpp"
 #include "VProperty.hpp"
 
 class QAction;
@@ -31,14 +31,14 @@ class PropertyMapper;
 class ServerHandler;
 class ServerUpdateData;
 
-
-class ServerRefreshInfoWidget : public QWidget, public ServerObserver, public ServerComObserver,
-                                public VPropertyObserver
-{
-Q_OBJECT
+class ServerRefreshInfoWidget : public QWidget,
+                                public ServerObserver,
+                                public ServerComObserver,
+                                public VPropertyObserver {
+    Q_OBJECT
 
 public:
-    explicit ServerRefreshInfoWidget(QAction* refreshAction,QWidget* parent=nullptr);
+    explicit ServerRefreshInfoWidget(QAction* refreshAction, QWidget* parent = nullptr);
     ~ServerRefreshInfoWidget() override;
 
     void setServer(ServerHandler* server);
@@ -64,7 +64,7 @@ protected Q_SLOTS:
     void slotTimeOutRefreshFinished();
 
 Q_SIGNALS:
-     void serverSettingsEditRequested(ServerHandler*);
+    void serverSettingsEditRequested(ServerHandler*);
 
 protected:
     void resizeEvent(QResizeEvent* event) override;
@@ -83,26 +83,26 @@ protected:
     QString formatPeriodTime(int timeInSec) const;
     void determinePeriodText();
     QString fullPeriodText() const;
-    int  determinePeriodTextWidthMin() const;
+    int determinePeriodTextWidthMin() const;
     bool periodTextWidthAboutToChange() const;
     void adjustGeometry(bool);
     void adjustTimer(int toNext);
     void adjustToolTip();
 
-    QString formatTime(int timeInSec) const;  
+    QString formatTime(int timeInSec) const;
     bool isInButton(const QPoint& pos) const;
     bool isInText(const QPoint& pos) const;
     void printStatus() const;
     bool isActionEnabled() const;
 
-    enum Component {ButtonComponent,TextComponent,ConfigComponent,NoComponent};
-    enum Mode {NormalMode,ManualMode,NoMode};
+    enum Component { ButtonComponent, TextComponent, ConfigComponent, NoComponent };
+    enum Mode { NormalMode, ManualMode, NoMode };
 
     QAction* refreshAction_;
     ServerHandler* server_;
     QString serverName_;
     QString serverText_;
-    QTimer *timer_;
+    QTimer* timer_;
     QElapsedTimer inRefreshElapsed_;
 
     QFont fontServer_;
@@ -113,25 +113,25 @@ protected:
     QFontMetrics fmPeriod_;
     QFontMetrics fmLast_;
 
-    static QIcon *icon_;
-    static QPen   borderPen_;
-    static QPen   buttonBorderPen_;
-    static QPen   disabledBorderPen_;
+    static QIcon* icon_;
+    static QPen borderPen_;
+    static QPen buttonBorderPen_;
+    static QPen disabledBorderPen_;
     static QBrush serverBgBrush_;
     static QBrush buttonBgBrush_;
     static QBrush buttonBgHoverBrush_;
-    static QPen   buttonHoverPen_;
+    static QPen buttonHoverPen_;
     static QBrush buttonBgRefreshBrush_;
-    static QPen   buttonRefreshPen_;
+    static QPen buttonRefreshPen_;
     static QBrush periodBgBrush_;
     static QBrush progBrush_;
     static QBrush progBgBrush_;
     static QBrush lastBgBrush_;
-    static QPen   serverTextPen_;
-    static QPen   periodTextPen_;
-    static QPen   driftTextPen_;
-    static QPen   lastTextPen_;
-    static QPen   disabledTextPen_;
+    static QPen serverTextPen_;
+    static QPen periodTextPen_;
+    static QPen driftTextPen_;
+    static QPen lastTextPen_;
+    static QPen disabledTextPen_;
 
     QRect buttonRect_;
     int buttonRadius2_;
@@ -154,7 +154,7 @@ protected:
     PropertyMapper* prop_;
 
     Mode mode_;
-    int  noBlinkLimit_;
+    int noBlinkLimit_;
     bool hasInfo_;
     bool inRefresh_;
     bool userInitiatedRefresh_;
@@ -166,16 +166,15 @@ protected:
     int toNext_;
     int drift_;
     bool needBorder_;
-
 };
 
 class ServerComActivityLine : public QWidget
 
 {
-//Q_OBJECT
+    // Q_OBJECT
 
 public:
-    explicit ServerComActivityLine(QWidget* parent=nullptr);
+    explicit ServerComActivityLine(QWidget* parent = nullptr);
 
     void setServer(ServerHandler* server);
 
@@ -186,7 +185,7 @@ protected:
     QFontMetrics fm_;
     ServerHandler* server_{nullptr};
     QPixmap pix_;
-    QTimer *timer_;
+    QTimer* timer_;
 };
 
 #if 0
@@ -203,5 +202,4 @@ protected:
 };
 #endif
 
-
 #endif // SERVERCOMLINE_HPP
