@@ -9,24 +9,21 @@
 //============================================================================
 
 #include "ShortcutHelpDialog.hpp"
-#include "DirectoryHandler.hpp"
-#include "SessionHandler.hpp"
 
 #include <QCloseEvent>
 #include <QFile>
 #include <QSettings>
 
+#include "DirectoryHandler.hpp"
+#include "SessionHandler.hpp"
 #include "ui_ShortcutHelpDialog.h"
 
-
-ShortcutHelpDialog::ShortcutHelpDialog(QWidget *parent) :
-    QDialog(parent),
-    ui_(new Ui::ShortcutHelpDialog)
-{
+ShortcutHelpDialog::ShortcutHelpDialog(QWidget* parent) : QDialog(parent), ui_(new Ui::ShortcutHelpDialog) {
     ui_->setupUi(this);
 
-    //Set css for the text formatting
-    QString cssDoc="td {padding-left: 3px; padding-right: 10px; paddig-top: 1px; padding-bottom: 1px; background-color: #F3F3F3;color: #323232;} \
+    // Set css for the text formatting
+    QString cssDoc =
+        "td {padding-left: 3px; padding-right: 10px; paddig-top: 1px; padding-bottom: 1px; background-color: #F3F3F3;color: #323232;} \
                     td.title {padding-left: 8px; padding-top: 2px; padding-bottom: 2px;background-color: #4769A0; color:#EBEEF1; font-weight: bold;}\
                     td.maintitle {padding-left: 8px; padding-top: 2px; padding-bottom: 2px;background-color:#765B8F ; color: #eeeeee;}\
                     td.first {font-weight: bold;}\
@@ -36,28 +33,24 @@ ShortcutHelpDialog::ShortcutHelpDialog(QWidget *parent) :
     ui_->tb->setReadOnly(true);
     ui_->tb->document()->setDefaultStyleSheet(cssDoc);
 
-    QString txtFile=QString::fromStdString(
-                DirectoryHandler::concatenate(DirectoryHandler::etcDir(), "shortcuts.txt"));
+    QString txtFile =
+        QString::fromStdString(DirectoryHandler::concatenate(DirectoryHandler::etcDir(), "shortcuts.txt"));
 
     loadText(txtFile);
 
     readSettings();
 }
 
-void ShortcutHelpDialog::loadText(QString fileName)
-{
+void ShortcutHelpDialog::loadText(QString fileName) {
     QString t = "<body><table width=\'100%\'>";
-    //t += "<tr><td class=\'maintitle\' colspan=\'2\'><h2>EcFlowUI</h2></td></tr>";
+    // t += "<tr><td class=\'maintitle\' colspan=\'2\'><h2>EcFlowUI</h2></td></tr>";
     t += "<tr><td class=\'empty\' colspan=\'2\'><h3>Keyboard shortcuts</h3></td></tr>";
 
     QFile f(fileName);
-    if(f.open(QIODevice::ReadOnly | QIODevice::Text))
-    {
-        while (!f.atEnd())
-        {
+    if (f.open(QIODevice::ReadOnly | QIODevice::Text)) {
+        while (!f.atEnd()) {
             QString line = f.readLine().simplified();
-            if(line.startsWith("||"))
-            {
+            if (line.startsWith("||")) {
                 QStringList lst = line.split("||");
                 t += "<tr>";
                 if (lst.count() >= 2) {
@@ -65,32 +58,26 @@ void ShortcutHelpDialog::loadText(QString fileName)
                 }
                 t += "</tr>";
             }
-            else if(line.startsWith("|"))
-            {
+            else if (line.startsWith("|")) {
                 QStringList lst = line.split("|");
                 t += "<tr>";
-                int cnt=0;
-                Q_FOREACH(QString s, lst)
-                {
-                    if(!s.isEmpty())
-                    {
-                        if (cnt==0)
-                        {
+                int cnt = 0;
+                Q_FOREACH (QString s, lst) {
+                    if (!s.isEmpty()) {
+                        if (cnt == 0) {
                             t += "<td class=\'first\'>";
                         }
-                        else
-                        {
+                        else {
                             t += "<td>";
                         }
 
                         t += s + "</td>";
                         cnt++;
-                   }
+                    }
                 }
                 t += "</tr>";
             }
-            else if(line.isEmpty())
-            {
+            else if (line.isEmpty()) {
                 t += "<tr><td class=\'empty\' colspan=\'2\'></tr>";
             }
         }
@@ -102,14 +89,12 @@ void ShortcutHelpDialog::loadText(QString fileName)
     ui_->tb->setHtml(t);
 }
 
-void ShortcutHelpDialog::accept()
-{
+void ShortcutHelpDialog::accept() {
     writeSettings();
     QDialog::accept();
 }
 
-void ShortcutHelpDialog::closeEvent(QCloseEvent *event)
-{
+void ShortcutHelpDialog::closeEvent(QCloseEvent* event) {
     writeSettings();
     event->accept();
 }
@@ -118,36 +103,30 @@ void ShortcutHelpDialog::closeEvent(QCloseEvent *event)
 // Settings read/write
 //------------------------------------------
 
-void ShortcutHelpDialog::writeSettings()
-{
-    SessionItem* cs=SessionHandler::instance()->current();
+void ShortcutHelpDialog::writeSettings() {
+    SessionItem* cs = SessionHandler::instance()->current();
     Q_ASSERT(cs);
-    QSettings settings(QString::fromStdString(cs->qtSettingsFile("ShortcutHelpDialog")),
-                       QSettings::NativeFormat);
+    QSettings settings(QString::fromStdString(cs->qtSettingsFile("ShortcutHelpDialog")), QSettings::NativeFormat);
 
-    //We have to clear it so that should not remember all the previous values
+    // We have to clear it so that should not remember all the previous values
     settings.clear();
 
     settings.beginGroup("main");
-    settings.setValue("size",size());
+    settings.setValue("size", size());
     settings.endGroup();
 }
 
-void ShortcutHelpDialog::readSettings()
-{
-    SessionItem* cs=SessionHandler::instance()->current();
+void ShortcutHelpDialog::readSettings() {
+    SessionItem* cs = SessionHandler::instance()->current();
     Q_ASSERT(cs);
-    QSettings settings(QString::fromStdString(cs->qtSettingsFile("ShortcutHelpDialog")),
-                       QSettings::NativeFormat);
+    QSettings settings(QString::fromStdString(cs->qtSettingsFile("ShortcutHelpDialog")), QSettings::NativeFormat);
 
     settings.beginGroup("main");
-    if(settings.contains("size"))
-    {
+    if (settings.contains("size")) {
         resize(settings.value("size").toSize());
     }
-    else
-    {
-        resize(QSize(630,660));
+    else {
+        resize(QSize(630, 660));
     }
     settings.endGroup();
 }
