@@ -10,10 +10,10 @@
 #ifndef TIMELINEINFOWIDGET_HPP
 #define TIMELINEINFOWIDGET_HPP
 
+#include <QAbstractItemModel>
 #include <QDialog>
 #include <QSettings>
 #include <QWidget>
-#include <QAbstractItemModel>
 
 #include "TimelineData.hpp"
 
@@ -24,27 +24,25 @@ class VNState;
 class NodeTimelineHeader;
 
 namespace Ui {
-    class TimelineInfoWidget;
+class TimelineInfoWidget;
 }
 
-class TimelineInfoModel : public QAbstractItemModel
-{
+class TimelineInfoModel : public QAbstractItemModel {
 public:
-    explicit TimelineInfoModel(QObject *parent=nullptr);
+    explicit TimelineInfoModel(QObject* parent = nullptr);
     ~TimelineInfoModel() override;
 
-    int columnCount (const QModelIndex& parent = QModelIndex() ) const override;
-    int rowCount (const QModelIndex& parent = QModelIndex() ) const override;
+    int columnCount(const QModelIndex& parent = QModelIndex()) const override;
+    int rowCount(const QModelIndex& parent = QModelIndex()) const override;
 
-    Qt::ItemFlags flags ( const QModelIndex & index) const override;
-    QVariant data (const QModelIndex& , int role = Qt::DisplayRole ) const override;
-    QVariant headerData(int,Qt::Orientation,int role = Qt::DisplayRole ) const override;
+    Qt::ItemFlags flags(const QModelIndex& index) const override;
+    QVariant data(const QModelIndex&, int role = Qt::DisplayRole) const override;
+    QVariant headerData(int, Qt::Orientation, int role = Qt::DisplayRole) const override;
 
-    QModelIndex index (int, int, const QModelIndex& parent = QModelIndex() ) const override;
-    QModelIndex parent (const QModelIndex & ) const override;
+    QModelIndex index(int, int, const QModelIndex& parent = QModelIndex()) const override;
+    QModelIndex parent(const QModelIndex&) const override;
 
-    void resetData(TimelineItem*,unsigned int viewStartDateSec,unsigned int viewEndDateSec,
-                 unsigned int endDateSec);
+    void resetData(TimelineItem*, unsigned int viewStartDateSec, unsigned int viewEndDateSec, unsigned int endDateSec);
     void clearData();
     bool hasData() const;
     void determineRowsInPeriod();
@@ -58,26 +56,24 @@ protected:
     int lastRowInPeriod_{-1};
 };
 
+// the main widget containing all components
+class TimelineInfoWidget : public QWidget {
+    Q_OBJECT
 
-//the main widget containing all components
-class TimelineInfoWidget : public QWidget
-{
-Q_OBJECT
-
-   friend class TimelineInfoDialog;
+    friend class TimelineInfoDialog;
 
 public:
-    explicit TimelineInfoWidget(QWidget *parent=nullptr);
+    explicit TimelineInfoWidget(QWidget* parent = nullptr);
     ~TimelineInfoWidget() override {}
 
     void clear();
-    void load(QString host,QString port,TimelineData*,int,QDateTime,QDateTime);
-    int itemIndex() const {return itemIndex_;}
+    void load(QString host, QString port, TimelineData*, int, QDateTime, QDateTime);
+    int itemIndex() const { return itemIndex_; }
 
 private:
     void createSummary();
-    void createSummary(QString &txt,VNState* state);
-    QPixmap makeBoxPlot(VNState* state, int num,int mean,TimelineItemStats stats);
+    void createSummary(QString& txt, VNState* state);
+    QPixmap makeBoxPlot(VNState* state, int num, int mean, TimelineItemStats stats);
     void updateInfoLabel() {}
     void readSettings(QSettings& settings);
     void writeSettings(QSettings& settings);
@@ -95,23 +91,21 @@ private:
     int tlEndTime_;
     int itemIndex_{-1};
 
-
-    //TimelineInfoDailyModel* dailyModel_;
+    // TimelineInfoDailyModel* dailyModel_;
     NodeTimelineHeader* dailyHeader_;
 
     static bool columnsAdjusted_;
 };
 
-class TimelineInfoDialog : public QDialog
-{
+class TimelineInfoDialog : public QDialog {
 public:
-    TimelineInfoDialog(QWidget* parent=nullptr);
+    TimelineInfoDialog(QWidget* parent = nullptr);
     ~TimelineInfoDialog() override;
 
     TimelineInfoWidget* infoW_;
 
 protected:
-    void closeEvent(QCloseEvent * event) override;
+    void closeEvent(QCloseEvent* event) override;
     void readSettings();
     void writeSettings();
 };
