@@ -10,10 +10,9 @@
 #ifndef TREENODEWIDGET_HPP_
 #define TREENODEWIDGET_HPP_
 
-#include "ui_TreeNodeWidget.h"
-
 #include "NodeWidget.hpp"
 #include "VProperty.hpp"
+#include "ui_TreeNodeWidget.h"
 
 class AttributeFilter;
 class NodeStateFilter;
@@ -21,17 +20,16 @@ class ServerFilter;
 class VParamFilterMenu;
 class VSettings;
 class VTreeServer;
-class TreeNodeWidget : public NodeWidget, public VPropertyObserver, protected Ui::TreeNodeWidget
-{
-Q_OBJECT
+class TreeNodeWidget : public NodeWidget, public VPropertyObserver, protected Ui::TreeNodeWidget {
+    Q_OBJECT
 
 public:
-	TreeNodeWidget(ServerFilter*,QWidget* parent=nullptr);
-	~TreeNodeWidget() override;
+    TreeNodeWidget(ServerFilter*, QWidget* parent = nullptr);
+    ~TreeNodeWidget() override;
 
-	void populateDockTitleBar(DashboardDockTitleWidget* tw) override;
+    void populateDockTitleBar(DashboardDockTitleWidget* tw) override;
 
-	void rerender() override;
+    void rerender() override;
     bool initialSelectionInView() override;
     void writeSettings(VComboSettings*) override;
     void readSettings(VComboSettings*) override;
@@ -39,26 +37,26 @@ public:
     void notifyChange(VProperty*) override;
 
 protected Q_SLOTS:
-	void on_actionBreadcrumbs_triggered(bool b);
-	void slotSelectionChangedInView(VInfo_ptr info);
-	void slotAttsChanged();
+    void on_actionBreadcrumbs_triggered(bool b);
+    void slotSelectionChangedInView(VInfo_ptr info);
+    void slotAttsChanged();
     void firstScanEnded(const VTreeServer*);
 
 protected:
-    enum ViewLayoutMode {StandardLayoutMode,CompactLayoutMode};
+    enum ViewLayoutMode { StandardLayoutMode, CompactLayoutMode };
 
     void initAtts();
     void detachedChanged() override {}
     void setViewLayoutMode(ViewLayoutMode);
 
-	VParamFilterMenu *stateFilterMenu_;
-	VParamFilterMenu *attrFilterMenu_;
-	VParamFilterMenu *iconFilterMenu_;
+    VParamFilterMenu* stateFilterMenu_;
+    VParamFilterMenu* attrFilterMenu_;
+    VParamFilterMenu* iconFilterMenu_;
 
     ViewLayoutMode viewLayoutMode_;
     VProperty* layoutProp_;
 
-	static AttributeFilter* lastAtts_;
+    static AttributeFilter* lastAtts_;
 
     std::string firstSelectionPath_;
 };
