@@ -11,30 +11,28 @@
 #ifndef TRIGGERITEMWIDGET_HPP_
 #define TRIGGERITEMWIDGET_HPP_
 
-#include <QtGlobal>
 #include <QWidget>
+#include <QtGlobal>
 
 #include "InfoPanelItem.hpp"
 #include "VInfo.hpp"
-
 #include "ui_TriggerItemWidget.h"
 
 class QAbstractButton;
 class QButtonGroup;
 class TriggeredScanner;
 
-class TriggerItemWidget : public QWidget, public InfoPanelItem, protected Ui::TriggerItemWidget
-{
-  friend class TriggerBrowser;
+class TriggerItemWidget : public QWidget, public InfoPanelItem, protected Ui::TriggerItemWidget {
+    friend class TriggerBrowser;
 
-Q_OBJECT
+    Q_OBJECT
 
 public:
-	explicit TriggerItemWidget(QWidget *parent=nullptr);
+    explicit TriggerItemWidget(QWidget* parent = nullptr);
     ~TriggerItemWidget() override;
 
-	void reload(VInfo_ptr) override;
-	QWidget* realWidget() override;
+    void reload(VInfo_ptr) override;
+    QWidget* realWidget() override;
     void clearContents() override;
 
     void nodeChanged(const VNode*, const std::vector<ecf::Aspect::Type>&) override;
@@ -54,8 +52,8 @@ protected Q_SLOTS:
     void scanProgressed(int);
     void slotHandleDefInfoWidgetClosure();
     void slotLinkSelected(VInfo_ptr info);
-    void slotInfoPanelCommand(VInfo_ptr info,QString cmd);
-    void slotDashboardCommand(VInfo_ptr info,QString cmd);
+    void slotInfoPanelCommand(VInfo_ptr info, QString cmd);
+    void slotDashboardCommand(VInfo_ptr info, QString cmd);
 #if QT_VERSION >= QT_VERSION_CHECK(6, 0, 0)
     void slotChangeMode(QAbstractButton*, bool);
 #else
@@ -68,18 +66,17 @@ protected:
     void loadGraph();
     void rerender() override;
     void updateState(const ChangeFlags&) override;
-    TriggeredScanner* triggeredScanner() const {return scanner_;}
+    TriggeredScanner* triggeredScanner() const { return scanner_; }
     void checkActionState();
     void clearTriggers();
     void showGraphButtons(bool b);
 
-    enum ModeIndex {TableModeIndex=0, GraphModeIndex=1};
+    enum ModeIndex { TableModeIndex = 0, GraphModeIndex = 1 };
 
-    TriggeredScanner *scanner_;  
+    TriggeredScanner* scanner_;
     QButtonGroup* modeGroup_;
     int exprHeight_;
     int exprEmptyHeight_;
 };
 
 #endif
-
