@@ -14,15 +14,13 @@
 
 class TriggerTableItem;
 
-class TriggerTextWidget : public QTextBrowser
-{
+class TriggerTextWidget : public QTextBrowser {
 public:
-    explicit TriggerTextWidget(QWidget *parent=nullptr);
+    explicit TriggerTextWidget(QWidget* parent = nullptr);
     void reloadItem(TriggerTableItem* item);
 
 private:
-    QString makeHtml(TriggerTableItem *ti,QString directTitle,QString modeText) const;
+    QString makeHtml(TriggerTableItem* ti, QString directTitle, QString modeText) const;
 };
 
 #endif
-
