@@ -11,40 +11,39 @@
 #ifndef VAUTOARCHIVEATTR_HPP
 #define VAUTOARCHIVEATTR_HPP
 
-#include "VAttribute.hpp"
-#include "VAttributeType.hpp"
-#include "AutoArchiveAttr.hpp"
-
-#include <QStringList>
 #include <string>
 #include <vector>
 
+#include <QStringList>
+
+#include "AutoArchiveAttr.hpp"
+#include "VAttribute.hpp"
+#include "VAttributeType.hpp"
+
 class AttributeFilter;
 class VAttributeType;
 class VNode;
 
-class VAutoArchiveAttrType : public VAttributeType
-{
+class VAutoArchiveAttrType : public VAttributeType {
 public:
     explicit VAutoArchiveAttrType();
     QString toolTip(QStringList d) const override;
     QString definition(QStringList d) const override;
-    void encode(ecf::AutoArchiveAttr*,QStringList&) const;
+    void encode(ecf::AutoArchiveAttr*, QStringList&) const;
 
 private:
-    enum DataIndex {TypeIndex=0,ValueIndex=1};
+    enum DataIndex { TypeIndex = 0, ValueIndex = 1 };
 };
 
-class VAutoArchiveAttr : public VAttribute
-{
+class VAutoArchiveAttr : public VAttribute {
 
 public:
-    VAutoArchiveAttr(VNode *parent);
+    VAutoArchiveAttr(VNode* parent);
 
     VAttributeType* type() const override;
     QStringList data(bool firstLine) const override;
 
-    static void scan(VNode* vnode,std::vector<VAttribute*>& vec);
+    static void scan(VNode* vnode, std::vector<VAttribute*>& vec);
 };
 
 #endif // VAUTOARCHIVEATTR_HPP
