@@ -11,42 +11,41 @@
 #ifndef VMETERATTR_HPP
 #define VMETERATTR_HPP
 
-#include "VAttribute.hpp"
-#include "VAttributeType.hpp"
-
-#include <QStringList>
 #include <string>
 #include <vector>
 
+#include <QStringList>
+
+#include "VAttribute.hpp"
+#include "VAttributeType.hpp"
+
 class AttributeFilter;
 class VAttributeType;
 class VNode;
 
 class Meter;
 
-class VMeterAttrType : public VAttributeType
-{
+class VMeterAttrType : public VAttributeType {
 public:
     explicit VMeterAttrType();
     QString toolTip(QStringList d) const override;
     QString definition(QStringList d) const override;
-    void encode(const Meter&,QStringList&) const;
+    void encode(const Meter&, QStringList&) const;
 
 private:
-    enum DataIndex {TypeIndex=0,NameIndex=1,ValueIndex=2,MinIndex=3, MaxIndex=4,ThresholdIndex=5};
+    enum DataIndex { TypeIndex = 0, NameIndex = 1, ValueIndex = 2, MinIndex = 3, MaxIndex = 4, ThresholdIndex = 5 };
 };
 
-class VMeterAttr : public VAttribute
-{
+class VMeterAttr : public VAttribute {
 
 public:
-    VMeterAttr(VNode *parent,const Meter&,int index);
+    VMeterAttr(VNode* parent, const Meter&, int index);
 
     VAttributeType* type() const override;
     QStringList data(bool firstLine) const override;
     std::string strName() const override;
 
-    static void scan(VNode* vnode,std::vector<VAttribute*>& vec);
+    static void scan(VNode* vnode, std::vector<VAttribute*>& vec);
 };
 
 #endif // VMETER_HPP
