@@ -12,8 +12,8 @@
 #define VNSTATE_HPP_
 
 #include <map>
-#include <vector>
 #include <string>
+#include <vector>
 
 #include "NState.hpp"
 #include "VParam.hpp"
@@ -22,44 +22,43 @@ class VNode;
 class ServerHandler;
 class VProperty;
 
-class VNState : public VParam
-{
+class VNState : public VParam {
 public:
-	VNState(const std::string& name,NState::State);
-	explicit VNState(const std::string& name);
+    VNState(const std::string& name, NState::State);
+    explicit VNState(const std::string& name);
 
-    //Nodes
-	static QString toName(const VNode*);
-	static QString toDefaultStateName(const VNode*);
+    // Nodes
+    static QString toName(const VNode*);
+    static QString toDefaultStateName(const VNode*);
     static QString toRealStateName(const VNode*);
-	static QColor  toColour(const VNode* n);
-	static QColor  toRealColour(const VNode* n);
-    static QColor  toFontColour(const VNode* n);
-    static QColor  toTypeColour(const VNode* n);
-	static VNState* toState(const VNode* n);
-	static VNState* toDefaultState(const VNode* n);
-	static VNState* toRealState(const VNode* n);
+    static QColor toColour(const VNode* n);
+    static QColor toRealColour(const VNode* n);
+    static QColor toFontColour(const VNode* n);
+    static QColor toTypeColour(const VNode* n);
+    static VNState* toState(const VNode* n);
+    static VNState* toDefaultState(const VNode* n);
+    static VNState* toRealState(const VNode* n);
 
-	//Server
-	static QString toName(ServerHandler*);
-	static QColor  toColour(ServerHandler*);
-	static VNState* toState(ServerHandler*);
-	static QColor  toFontColour(ServerHandler*);
+    // Server
+    static QString toName(ServerHandler*);
+    static QColor toColour(ServerHandler*);
+    static VNState* toState(ServerHandler*);
+    static QColor toFontColour(ServerHandler*);
 
-	static std::vector<VParam*> filterItems();
-	static VNState* find(const std::string& name);
+    static std::vector<VParam*> filterItems();
+    static VNState* find(const std::string& name);
     static VNState* find(unsigned char ucId);
     static bool isActive(unsigned char ucId);
     static bool isComplete(unsigned char ucId);
     static bool isSubmitted(unsigned char ucId);
 
-    unsigned char ucId() const {return ucId_;}
+    unsigned char ucId() const { return ucId_; }
 
-    //Called from VConfigLoader
+    // Called from VConfigLoader
     static void load(VProperty*);
 
 private:
-	static std::map<std::string,VNState*> items_;
+    static std::map<std::string, VNState*> items_;
     unsigned char ucId_{0};
 };
 
