@@ -12,25 +12,22 @@
 
 #include <vector>
 
-using Vec = std::vector<VSettingsLoader *>;
+using Vec          = std::vector<VSettingsLoader*>;
 
 static Vec* makers = nullptr;
 
-VSettingsLoader::VSettingsLoader()
-{
-    if(makers == nullptr)
+VSettingsLoader::VSettingsLoader() {
+    if (makers == nullptr)
         makers = new Vec();
 
     makers->push_back(Vec::value_type(this));
 }
 
-void VSettingsLoader::process()
-{
-    if(!makers)
+void VSettingsLoader::process() {
+    if (!makers)
         return;
 
-    for(auto & maker : *makers)
-    {
+    for (auto& maker : *makers) {
         maker->loadSettings();
     }
 }
