@@ -19,30 +19,33 @@ class QProgressBar;
 class QToolButton;
 class QTimer;
 
-class DelayedProgressDef
-{
+class DelayedProgressDef {
 public:
     DelayedProgressDef() = default;
-    DelayedProgressDef(QString text, int max=0) : infoText_(text), max_(max) {}
-    void clear() {infoText_.clear(); progText_.clear(); max_=0; progVal_=0;}
+    DelayedProgressDef(QString text, int max = 0) : infoText_(text), max_(max) {}
+    void clear() {
+        infoText_.clear();
+        progText_.clear();
+        max_     = 0;
+        progVal_ = 0;
+    }
     QString infoText_;
     QString progText_;
     int max_{0};
     int progVal_{0};
 };
 
-class MessageLabelProgWidget : public QWidget
-{
+class MessageLabelProgWidget : public QWidget {
     Q_OBJECT
 
 public:
-    MessageLabelProgWidget(QWidget *parent);
+    MessageLabelProgWidget(QWidget* parent);
 
     void startProgress(int max);
     void showProgressCancelButton(bool);
     void stopProgress();
-    void progress(QString text,int value);
-    void startDelayedProgress(QString text, int max=0);
+    void progress(QString text, int value);
+    void startDelayedProgress(QString text, int max = 0);
 
 protected Q_SLOTS:
     void cancelButtonClicked();
@@ -53,7 +56,7 @@ Q_SIGNALS:
     void stoppedByButton();
 
 private:
-    QLabel*  progLabel_{nullptr};
+    QLabel* progLabel_{nullptr};
     QProgressBar* progBar_{nullptr};
     QToolButton* progCancelTb_{nullptr};
     QTimer* delayedProgressTimer_{nullptr};
@@ -61,12 +64,11 @@ private:
     int delayInMs_{500}; // ms
 };
 
-class MessageLabelLoadWidget : public QWidget
-{
+class MessageLabelLoadWidget : public QWidget {
     Q_OBJECT
 
 public:
-    MessageLabelLoadWidget(QWidget *parent);
+    MessageLabelLoadWidget(QWidget* parent);
     void startLoadLabel(bool showCacelButton);
     void stopLoadLabel();
 
@@ -82,31 +84,30 @@ private:
     QToolButton* loadCancelTb_{nullptr};
 };
 
-class MessageLabel : public QWidget
-{
+class MessageLabel : public QWidget {
     Q_OBJECT
 public:
-	explicit MessageLabel(QWidget *parent=nullptr);
+    explicit MessageLabel(QWidget* parent = nullptr);
 
-    enum Type {NoType,InfoType,WarningType,ErrorType,TipType};
+    enum Type { NoType, InfoType, WarningType, ErrorType, TipType };
 
-	void showWarning(QString);
+    void showWarning(QString);
     void showError(QString);
     void showTip(QString);
     void appendInfo(QString);
     void appendWarning(QString);
     void appendError(QString);
     void appendTip(QString);
-    void startLoadLabel(bool showCacelButton=false);
+    void startLoadLabel(bool showCacelButton = false);
     void stopLoadLabel();
 
-    void startProgress(int max=0);
+    void startProgress(int max = 0);
     void stopProgress();
-    void progress(QString text,int value);
-    void startDelayedProgress(QString text, int max=0);
+    void progress(QString text, int value);
+    void startDelayedProgress(QString text, int max = 0);
 
-	void setShowTypeTitle(bool);
-	void clear();
+    void setShowTypeTitle(bool);
+    void clear();
     void setNarrowMode(bool);
 
 public Q_SLOTS:
@@ -117,17 +118,17 @@ Q_SIGNALS:
     void progressStoppedByButton();
 
 protected:
-    void paintEvent(QPaintEvent *) override;
+    void paintEvent(QPaintEvent*) override;
 
 private:
-    void showMessage(const Type&,QString);
-    void appendMessage(const Type&,QString);
+    void showMessage(const Type&, QString);
+    void appendMessage(const Type&, QString);
 
     bool showTypeTitle_{true};
     bool narrowMode_{false};
     Type currentType_{NoType};
     QHBoxLayout* layout_;
-    QLabel *pixLabel_{nullptr};
+    QLabel* pixLabel_{nullptr};
     QLabel* msgLabel_{nullptr};
     MessageLabelLoadWidget* loadWidget_{nullptr};
     MessageLabelProgWidget* progWidget_{nullptr};
@@ -135,4 +136,3 @@ private:
 };
 
 #endif
-
